@@ -1,15 +1,31 @@
 #!/usr/bin/env python
+"""runp.
+
+This repository is a modified of runp, which is no longer maintained, for modern Python 3.
+
+runp exports Python functions from files to the command line.
+You don't need to change your existing code.
+"""
+
 import sys
 import argparse
 import inspect
 import pydoc
-from typing import Any, Dict, List, Tuple, Callable, Optional
+from typing import Dict, List, Tuple, Callable, Optional
 from pathlib import Path
 from types import ModuleType
 from collections.abc import ItemsView
 
 
 def filter_vars(imported_vars: ItemsView) -> Dict[str, Callable]:
+    """Gets the name and object of the callable object from the imported_vars.
+
+    Args:
+        imported_vars (ItemsView): python module items iterator.
+
+    Returns:
+        Dict[str, Callable]: dictionary of name and callable object
+    """
     functions = {}
     for name, obj in imported_vars:
         if callable(obj) and not name.startswith('_'):
@@ -24,6 +40,14 @@ def filter_vars(imported_vars: ItemsView) -> Dict[str, Callable]:
 
 
 def load_runfile(runfile: Path) -> ItemsView:
+    """Load Python file.
+
+    Args:
+        runfile (Path): Python file path.
+
+    Returns:
+        ItemsView: python module items iterator.
+    """
     importer = __import__
     directory, runfile = runfile.parent, Path(runfile.name)
 
@@ -34,7 +58,16 @@ def load_runfile(runfile: Path) -> ItemsView:
     return imported_vars
 
 
-def _escape_split(sep: str, argstr: str) -> str:
+def _escape_split(sep: str, argstr: str) -> List[str]:
+    """Split function with escape characters.
+
+    Args:
+        sep (str): Split character.
+        argstr (str): String to be divided.
+
+    Returns:
+        List[str]: List of splited strings.
+    """
     escaped_sep = r'\%s' % sep
 
     if escaped_sep not in argstr:
@@ -50,6 +83,15 @@ def _escape_split(sep: str, argstr: str) -> str:
 
 
 def parse_args(cmd: str) -> Tuple[str, List[str], Dict[str, str]]:
+    """Argment parser.
+
+    Args:
+        cmd (str): argment.
+
+    Returns:
+        Tuple[str, List[str], Dict[str, str]]: original argument,
+        positional argument, and key word argument.
+    """
     args = []
     kwargs = {}
     if ':' in cmd:
@@ -64,17 +106,34 @@ def parse_args(cmd: str) -> Tuple[str, List[str], Dict[str, str]]:
     return cmd, args, kwargs
 
 
-def get_docstring(function: Callable, abbrv=False) -> Optional[str]:
-    try:
-        doc = inspect.getdoc(function)
-        if abbrv:
-            doc = doc.splitlines()[0].strip()
-    except:
+def get_docstring(function: Callable, abbrv: bool = False) -> str:
+    """Get docstring.
+
+    Args:
+        function (Callable): targe callable object
+        abbrv (bool, optional): Defaults to False.
+
+    Returns:
+        str: docstring.
+    """
+    doc = inspect.getdoc(function)
+    if abbrv and doc is not None:
+        doc = doc.splitlines()[0].strip()
+    else:
         doc = ""
     return doc
 
 
 def get_function(functions: Dict[str, Callable], function_name: str) -> Optional[Callable]:
+    """Get function.
+
+    Args:
+        functions (Dict[str, Callable]): original function dictionaly.
+        function_name (str): search function name.
+
+    Returns:
+        Optional[Callable]: find callable object.
+    """
     try:
         return functions[function_name]
     except KeyError:
@@ -83,13 +142,24 @@ def get_function(functions: Dict[str, Callable], function_name: str) -> Optional
 
 
 def print_functions(functions: Dict[str, Callable]) -> None:
+    """Print functions list.
+
+    Args:
+        functions (Dict[str, Callable]): Print functions
+    """
     print("Available functions:")
     for fname, function in functions.items():
         doc = get_docstring(function, abbrv=True)
-        print(fname + "\t" + doc)
+        print(fname + "\t" + doc if doc is not None else "")
 
 
 def print_function(functions: Dict[str, Callable], function: str) -> None:
+    """Print function.
+
+    Args:
+        functions (Dict[str, Callable]): Print functions.
+        function (str): function name.
+    """
     func = get_function(functions, function)
     if func:
         print(pydoc.plain(pydoc.render_doc(
@@ -99,6 +169,12 @@ def print_function(functions: Dict[str, Callable], function: str) -> None:
 
 
 def run_function(functions: Dict[str, Callable], cmd: str) -> None:
+    """Run function.
+
+    Args:
+        functions (Dict[str, Callable]): Print functions.
+        cmd (str): command.
+    """
     function, args, kwargs = parse_args(cmd)
     try:
         func = get_function(functions, function)
@@ -108,11 +184,21 @@ def run_function(functions: Dict[str, Callable], cmd: str) -> None:
         print(e.args[0])
 
 
-def main(*argv: Tuple[Any]) -> None:
+def main(argv: List[str]) -> None:
+    """Main function.
 
-    parser = argparse.ArgumentParser(description='Run functions in a file.')
-    parser.add_argument('runfile', help='file containing the functions')
-    parser.add_argument('function', nargs='?', help='function to run')
+    Args:
+        argv (List[str]): command line arguments.
+    """
+    parser = argparse.ArgumentParser(
+        prog="runp",
+        description='Run functions in a file.')
+    parser.add_argument(
+        'runfile',
+        help='file containing the functions')
+    parser.add_argument(
+        'function',
+        nargs='?', help='function to run')
     parser.add_argument(
         '-l', '--list',
         action='store_true',
@@ -122,11 +208,11 @@ def main(*argv: Tuple[Any]) -> None:
         '-d', '--detail',
         help='print function docstring'
     )
-    args = parser.parse_args(*argv)
+    args = parser.parse_args(argv)
 
     runfile = Path(args.runfile).resolve()
 
-    if not runfile.is_file:
+    if not runfile.is_file():
         print("No such file '{}'".format(args.runfile))
         sys.exit(1)
 
@@ -144,6 +230,7 @@ def main(*argv: Tuple[Any]) -> None:
     if args.function is None:
         print("No function was selected!")
         sys.exit(1)
+
     run_function(functions, args.function)
 
 
